#
# spec file for package issue-generator
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           issue-generator
Version:        1.13
Release:        2.2
Summary:        Generates an issue files from different snippets
License:        GPL-2.0-or-later
Group:          System/Base
URL:            https://github.com/thkukuk/issue-generator
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
Requires(post): %fillup_prereq
BuildArch:      noarch

%description
issue-generator is a tool to create an issue file dynamically.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}
%ifarch s390x
# Adjust regex in sysconfig/issue-generator for s390x
sed -i -e 's|NETWORK_INTERFACE_REGEX=.*|NETWORK_INTERFACE_REGEX="^[beqich]"|g' udev/sysconfig.issue-generator
%endif

%install
%make_install
mkdir -p %{buildroot}%{_fillupdir}
install -m 644 udev/sysconfig.issue-generator %{buildroot}%{_fillupdir}/
%fdupes %{buildroot}%{_mandir}

%pre
%service_add_pre issue-generator.service issue-generator.path issue-add-ssh-keys.service

%post
%tmpfiles_create issue-generator.conf
%{fillup_only -n issue-generator}
%service_add_post issue-generator.service issue-generator.path issue-add-ssh-keys.service

%preun
%service_del_preun issue-generator.service issue-generator.path issue-add-ssh-keys.service

%postun
%service_del_postun issue-generator.service issue-generator.path issue-add-ssh-keys.service

%files
%license COPYING
%doc NEWS README.md
%dir %{_sysconfdir}/issue.d
%dir %{_prefix}/lib/issue.d
%dir %{_prefix}/lib/tmpfiles.d
%dir %{_prefix}/lib/udev
%dir %{_prefix}/lib/udev/rules.d
%{_fillupdir}/sysconfig.issue-generator
%{_prefix}/lib/tmpfiles.d/issue-generator.conf
%{_prefix}/lib/udev/rules.d/90-issue-generator.rules
%{_prefix}/lib/systemd/system/issue-add-ssh-keys.service
%{_prefix}/lib/systemd/system/issue-generator.path
%{_prefix}/lib/systemd/system/issue-generator.service
%{_sbindir}/issue-generator
%{_mandir}/man5/issue.d.5%{ext_man}
%{_mandir}/man8/issue-generator.8%{ext_man}
%{_mandir}/man8/90-issue-generator.rules.8%{ext_man}
%{_mandir}/man8/issue-add-ssh-keys.service.8%{ext_man}
%{_mandir}/man8/issue-generator.conf.8%{ext_man}
%{_mandir}/man8/issue-generator.service.8%{ext_man}

%changelog
* Tue Jun 18 2024 Thorsten Kukuk <kukuk@suse.com>
- Remove rc* symlinks [jsc#PED-266]
* Thu May 27 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.13
  - SELinux: Do not call agetty --reload [bsc#1186178]
* Wed Oct 21 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.12
  - Update manual page
  - Use python3 instead of python 2.x
* Mon Oct 19 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.11
  - Don't display issue.d/*.issue files, agetty will do that [bsc#1177891]
  - Ignore /run/issue.d in issue-generator.path, else issue-generator will
    be called too fast too often [bsc#1177865]
  - Ignore *.bak, *~ and *.rpm* files [bsc#1118862]
* Tue Oct  6 2020 Fabian Vogt <fvogt@suse.com>
- Handle the .path unit in scriptlets as well
* Tue Jul  7 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.10
  - Display wlan interfaces [bsc#1169070]
* Thu Apr 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.9
  - Fix path for systemd files
* Wed Feb 12 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.8
  - Handle network interface renames
* Fri Jan 11 2019 kukuk@suse.de
- Update to version 1.7
  - automatically generate issue file [bsc#1116825]
* Mon Jun  4 2018 kukuk@suse.de
- Update to version 1.6
  - Fix permission of /run/issue [bsc#1095697]
* Fri May 18 2018 kukuk@suse.de
- Update to version 1.5
  - don't replace issue file or reload agetty if there were no
    changes (found due to [bsc#1085196]).
* Fri Feb 23 2018 kukuk@suse.com
- Use %%license instead of %%doc [bsc#1082318]
* Wed Feb  7 2018 kukuk@suse.de
- Update to version 1.4
  - check if agetty is available
  - adjust to changed ssh-keygen output
* Wed Dec 13 2017 kukuk@suse.de
- Enable more network devices to be shown on s390x [bsc#1071776]
- Remove systemd require again, systemd-preset-branding is fixed.
* Fri Dec  8 2017 kukuk@suse.com
- Readd require for systemd, else package will be installed too
  early and services will never be enabled [bsc#1071776]
* Tue Nov 28 2017 kukuk@suse.de
- Use official systemd macros in %%post install
* Tue Nov 28 2017 kukuk@suse.de
- Don't require systemd: if it's there, we will use it, if it is
  not there like in a base container image, there is nothing to do
  for us.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed May 31 2017 kukuk@suse.de
- Remove ghost entry for /etc/issue [bsc#1038526]
* Tue Mar 28 2017 kukuk@suse.de
- Update to version 1.3
  - make list of network interfaces configureable
* Fri Nov 25 2016 kukuk@suse.de
- Fix typo in spec file
* Wed Nov 23 2016 kukuk@suse.de
- Update to version 1.2
  - add additional docu
* Tue Nov 15 2016 kukuk@suse.de
- Update to version 1.1
  - fix several typos
  - relead agetty if we modify /run/issue
* Tue Nov 15 2016 kukuk@suse.de
- Use correct systemd macros
* Wed Nov  2 2016 kukuk@suse.de
- Update to version 1.0
* Tue Nov  1 2016 kukuk@suse.de
- Add directories for udev to filelist
* Fri Oct 28 2016 kukuk@suse.de
- Initial version
